@@ -11,7 +11,7 @@ from .label import lumitext
 # Log styles
 from .styles import alice as style
 
-__all__ = ("style", "lumitext")
+__all__ = ("lumitext", "style")
 
 
 @docstring.copy(label_base.exp_text)
