@@ -403,11 +403,19 @@ def exp_label(
             _com_label = r"\mathrm{13\ TeV}"
 
         if lumi is not None:
-            _lumi = (
-                r"$\sqrt{s} = " + _com_label + ", " + str(lumi) + r"\ \mathrm{fb}^{-1}$"
+            _lumi = r"{com}, {lumi}".format(
+                com=r"$\sqrt{s} = \mathrm{" + str(com) + r"\ TeV}$"
+                if com is not None
+                else r"$\sqrt{s} = \mathrm{13\ TeV}$",
+                lumi=lumi_format.format(lumi) + r" $\mathrm{fb^{-1}}$",
             )
         else:
-            _lumi = r"$\sqrt{s} = " + _com_label + "$"
+            _lumi = r"{com}".format(
+                com=r"$\sqrt{s} = \mathrm{" + str(com) + r"\ TeV}$"
+                if com is not None
+                else r"$\sqrt{s} = \mathrm{13\ TeV}$",
+            )
+
         explumi = ExpSuffix(
             *exptext.get_position(),
             text=rlabel if rlabel is not None else _lumi,
@@ -547,7 +555,7 @@ def save_variations(fig, name, text_list=None, exp=None):
     if text_list is None:
         text_list = ["Preliminary", ""]
 
-    from mplhep.label import ExpSuffix, ExpText
+    from mplhep.label import ExpSuffix, ExpText  # noqa: PLC0415
 
     for text in text_list:
         for ax in fig.get_axes():
