@@ -9,7 +9,10 @@ from typing import TYPE_CHECKING, Any, NamedTuple, Union
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import numpy as np
+from matplotlib.lines import Line2D
 from matplotlib.offsetbox import AnchoredText
+from matplotlib.patches import Patch, Rectangle
+from matplotlib.text import Text
 from matplotlib.transforms import Bbox
 from mpl_toolkits.axes_grid1 import axes_size, make_axes_locatable
 
@@ -85,6 +88,7 @@ def histplot(
     sort=None,
     edges=True,
     binticks=False,
+    xoffsets=None,
     ax: mpl.axes.Axes | None = None,
     flow="hint",
     **kwargs,
@@ -147,6 +151,8 @@ def histplot(
             Specifies whether to draw first and last edges of the histogram
         binticks : bool, default: False, optional
             Attempts to draw x-axis ticks coinciding with bin boundaries if feasible.
+        xoffsets: bool, default: False,
+            If True, the bin "centers" of plotted histograms will be offset within their bin.
         ax : matplotlib.axes.Axes, optional
             Axes object (if None, last one is fetched or one is created)
         flow :  str, optional { "show", "sum", "hint", "none"}
@@ -178,6 +184,17 @@ def histplot(
         "hint",
         "none",
     }, "flow must be show, sum, hint, or none"
+    if hasattr(H, "values") or hasattr(H[0], "values"):  # Check for hist-like inputs
+        assert bins is None, (
+            "When plotting hist(-like) objects, specifying bins is not allowed."
+        )
+        assert w2 is None, (
+            "When plotting hist(-like) objects, specifying w2 is not allowed."
+        )
+    if w2 is not None:
+        assert np.array(w2).shape == np.array(H).shape, (
+            "w2 must have the same shape as H"
+        )
 
     # Convert 1/0 etc to real bools
     stack = bool(stack)
@@ -198,6 +215,60 @@ def histplot(
         else get_histogram_axes_title(hists[0].axes[0])
     )
 
+    _labels: list[str | None]
+    if label is None:
+        _labels = [None] * len(hists)
+    elif isinstance(label, str):
+        _labels = [label] * len(hists)
+    elif not np.iterable(label):
+        _labels = [str(label)] * len(hists)
+    else:
+        _labels = [str(lab) for lab in label]
+
+    def iterable_not_string(arg):
+        return isinstance(arg, collections.abc.Iterable) and not isinstance(arg, str)
+
+    _chunked_kwargs: list[dict[str, Any]] = []
+    for _ in range(len(hists)):
+        _chunked_kwargs.append({})
+    for kwarg, kwarg_content in kwargs.items():
+        # Check if iterable
+        if iterable_not_string(kwarg_content):
+            # Check if tuple of floats or ints (can be used for colors)
+            if isinstance(kwarg_content, tuple) and all(
+                isinstance(x, (int, float)) for x in kwarg_content
+            ):
+                for i in range(len(_chunked_kwargs)):
+                    _chunked_kwargs[i][kwarg] = kwarg_content
+            else:
+                for i, kw in enumerate(kwarg_content):
+                    _chunked_kwargs[i][kwarg] = kw
+        else:
+            for i in range(len(_chunked_kwargs)):
+                _chunked_kwargs[i][kwarg] = kwarg_content
+
+    # Sorting
+    if sort is not None:
+        if isinstance(sort, str):
+            if sort.split("_")[0] in ["l", "label"] and isinstance(_labels, list):
+                order = np.argsort(label)  # [::-1]
+            elif sort.split("_")[0] in ["y", "yield"]:
+                _yields = [np.sum(_h.values()) for _h in hists]  # type: ignore[var-annotated]
+                order = np.argsort(_yields)
+            if len(sort.split("_")) == 2 and sort.split("_")[1] == "r":
+                order = order[::-1]
+        elif isinstance(sort, (list, np.ndarray)):
+            if len(sort) != len(hists):
+                msg = f"Sort indexing array is of the wrong size - {len(sort)}, {len(hists)} expected."
+                raise ValueError(msg)
+            order = np.asarray(sort)
+        else:
+            msg = f"Sort type: {sort} not understood."
+            raise ValueError(msg)
+        hists = [hists[ix] for ix in order]
+        _chunked_kwargs = [_chunked_kwargs[ix] for ix in order]
+        _labels = [_labels[ix] for ix in order]
+
     plottables, flow_info = get_plottables(
         hists,
         bins=final_bins,
@@ -208,63 +279,10 @@ def histplot(
         density=density,
         binwnorm=binwnorm,
         flow=flow,
+        xoffsets=xoffsets,
     )
     flow_bins, underflow, overflow = flow_info
 
-    _labels: list[str | None]
-    if label is None:
-        _labels = [None] * len(plottables)
-    elif isinstance(label, str):
-        _labels = [label] * len(plottables)
-    elif not np.iterable(label):
-        _labels = [str(label)] * len(plottables)
-    else:
-        _labels = [str(lab) for lab in label]
-
-    def iterable_not_string(arg):
-        return isinstance(arg, collections.abc.Iterable) and not isinstance(arg, str)
-
-    _chunked_kwargs: list[dict[str, Any]] = []
-    for _ in range(len(plottables)):
-        _chunked_kwargs.append({})
-    for kwarg in kwargs:
-        # Check if iterable
-        if iterable_not_string(kwargs[kwarg]):
-            # Check if tuple of floats or ints (can be used for colors)
-            if isinstance(kwargs[kwarg], tuple) and all(
-                isinstance(x, (int, float)) for x in kwargs[kwarg]
-            ):
-                for i in range(len(_chunked_kwargs)):
-                    _chunked_kwargs[i][kwarg] = kwargs[kwarg]
-            else:
-                for i, kw in enumerate(kwargs[kwarg]):
-                    _chunked_kwargs[i][kwarg] = kw
-        else:
-            for i in range(len(_chunked_kwargs)):
-                _chunked_kwargs[i][kwarg] = kwargs[kwarg]
-
-    # Sorting
-    if sort is not None:
-        if isinstance(sort, str):
-            if sort.split("_")[0] in ["l", "label"] and isinstance(_labels, list):
-                order = np.argsort(label)  # [::-1]
-            elif sort.split("_")[0] in ["y", "yield"]:
-                _yields = [np.sum(_h.values) for _h in plottables]  # type: ignore[var-annotated]
-                order = np.argsort(_yields)
-            if len(sort.split("_")) == 2 and sort.split("_")[1] == "r":
-                order = order[::-1]
-        elif isinstance(sort, (list, np.ndarray)):
-            if len(sort) != len(plottables):
-                msg = f"Sort indexing array is of the wrong size - {len(sort)}, {len(plottables)} expected."
-                raise ValueError(msg)
-            order = np.asarray(sort)
-        else:
-            msg = f"Sort type: {sort} not understood."
-            raise ValueError(msg)
-        plottables = [plottables[ix] for ix in order]
-        _chunked_kwargs = [_chunked_kwargs[ix] for ix in order]
-        _labels = [_labels[ix] for ix in order]
-
     ##########
     # Plotting
     return_artists: list[StairsArtists | ErrorBarArtists] = []
@@ -274,7 +292,7 @@ def histplot(
     elif histtype == "barstep" and len(plottables) == 1:
         histtype = "step"
 
-    # customize color cycle assignment when stacking to match legend
+    # # customize color cycle assignment when stacking to match legend
     if stack:
         plottables = plottables[::-1]
         _chunked_kwargs = _chunked_kwargs[::-1]
@@ -301,7 +319,8 @@ def histplot(
     if "step" in histtype:
         for i in range(len(plottables)):
             do_errors = yerr is not False and (
-                (yerr is not None or w2 is not None) or plottables[i]._has_variances
+                (yerr is not None or w2 is not None)
+                or plottables[i].variances() is not None
             )
 
             _kwargs = _chunked_kwargs[i]
@@ -331,6 +350,7 @@ def histplot(
                     _ls = _kwargs.pop("linestyle", "-")
                     _kwargs["linestyle"] = "none"
                     _plot_info = plottables[i].to_errorbar()
+                    del _plot_info["xerr"]
                     _e = ax.errorbar(
                         **_plot_info,
                         **_kwargs,
@@ -362,7 +382,7 @@ def histplot(
 
                 _b = ax.bar(
                     plottables[i].centers + _shift[i],
-                    plottables[i].values,
+                    plottables[i].values(),
                     width=_full_bin_width / len(plottables),
                     label=_step_label,
                     align="center",
@@ -407,7 +427,7 @@ def histplot(
 
             _b = ax.bar(
                 plottables[i].centers + _shift[i],
-                plottables[i].values,
+                plottables[i].values(),
                 width=_full_bin_width / len(plottables),
                 label=_labels[i],
                 align="center",
@@ -466,7 +486,12 @@ def histplot(
             _plot_info = plottables[i].to_errorbar()
             if yerr is False:
                 _plot_info["yerr"] = None
-            _plot_info["xerr"] = _xerr
+            if not xerr:
+                del _plot_info["xerr"]
+            if isinstance(xerr, (int, float)) and not isinstance(xerr, bool):
+                _plot_info["xerr"] = xerr
+            elif isinstance(xerr, (np.ndarray, list)):
+                _plot_info["xerr"] = xerr[i]
             _e = ax.errorbar(
                 **_plot_info,
                 label=_labels[i],
@@ -484,7 +509,7 @@ def histplot(
 
     if xtick_labels is None or flow == "show":
         if binticks:
-            _slice = int(round(float(len(final_bins)) / len(ax.get_xticks()))) + 1
+            _slice = round(float(len(final_bins)) / len(ax.get_xticks())) + 1
             ax.set_xticks(final_bins[::_slice])
     else:
         ax.set_xticks(_bin_centers)
@@ -554,7 +579,7 @@ def histplot(
                 xticklabels = _xticklabels
 
         lw = ax.spines["bottom"].get_linewidth()
-        _edges = plottables[0].edges
+        _edges = plottables[0].edges_1d()
         _centers = plottables[0].centers
         _marker_size = (
             20
@@ -655,6 +680,9 @@ def hist2dplot(
     xbins=None,
     ybins=None,
     labels=None,
+    labels_fontsize=None,
+    labels_round=None,
+    labels_color=None,
     cbar: bool = True,
     cbarsize="7%",
     cbarpad=0.2,
@@ -686,6 +714,12 @@ def hist2dplot(
     labels : 2D array (H-like) or bool, default None, optional
         Array of per-bin labels to display. If ``True`` will
         display numerical values
+    labels_fontsize : float, optional, default None
+        Fontsize of labels.
+    labels_color : str, optional, default None
+        Color of labels. If not given, will be decided automatically.
+    labels_round : int, optional, default None
+        Round labels to given number of decimals
     cbar : bool, optional, default True
         Draw a colorbar. In contrast to mpl behaviors the cbar axes is
         appended in such a way that it doesn't modify the original axes
@@ -788,7 +822,7 @@ def hist2dplot(
         except TypeError as error:
             if "got an unexpected keyword argument 'flow'" in str(error):
                 msg = (
-                    f"The histograms value method {h!r} does not take a 'flow' argument. UHI Plottable doesn't require this to have, but it is required for this function."
+                    f"The histograms value method {h!r} does not take a 'flow' argument. UHI PlottableHistogram doesn't require this to have, but it is required for this function."
                     f" Implementations like hist/boost-histogram support this argument."
                 )
                 raise TypeError(msg) from error
@@ -971,15 +1005,23 @@ def hist2dplot(
         for ix, xc in enumerate(xbin_centers):
             for iy, yc in enumerate(ybin_centers):
                 normedh = pc.norm(H[iy, ix])
-                color = "black" if isLight(pccmap(normedh)[:-1]) else "lightgrey"
+                if labels_color is not None:
+                    color = labels_color
+                else:
+                    color = "black" if isLight(pccmap(normedh)[:-1]) else "lightgrey"
                 text_artists.append(
                     ax.text(
                         xc,
                         yc,
-                        _labels[iy, ix],  # type: ignore[arg-type]
+                        (
+                            _labels[iy, ix].round(labels_round)  # type: ignore[arg-type]
+                            if labels_round is not None
+                            else _labels[iy, ix]
+                        ),
                         ha="center",
                         va="center",
                         color=color,
+                        fontsize=labels_fontsize,
                     )
                 )
 
@@ -992,9 +1034,6 @@ def overlap(ax, bbox, get_vertices=False):
     """
     Find overlap of bbox for drawn elements an axes.
     """
-    from matplotlib.lines import Line2D
-    from matplotlib.patches import Patch, Rectangle
-    from matplotlib.text import Text
 
     # From
     # https://github.com/matplotlib/matplotlib/blob/08008d5cb4d1f27692e9aead9a76396adc8f0b19/lib/matplotlib/legend.py#L845
@@ -1332,13 +1371,13 @@ def append_axes(ax, size=0.1, pad=0.1, position="right", extend=False):
                 fig.get_size_inches()[1],
             )
         elif position in ["left"]:
-            divider.set_horizontal(xsizes[::-1] + [axes_size.Fixed(width)])
+            divider.set_horizontal([*xsizes[::-1], axes_size.Fixed(width)])
             fig.set_size_inches(
                 fig.get_size_inches()[0] * extend_ratio(ax, yhax)[0],
                 fig.get_size_inches()[1],
             )
         elif position in ["top"]:
-            divider.set_vertical([axes_size.Fixed(height)] + xsizes[::-1])
+            divider.set_vertical([axes_size.Fixed(height), *xsizes[::-1]])
             fig.set_size_inches(
                 fig.get_size_inches()[0],
                 fig.get_size_inches()[1] * extend_ratio(ax, yhax)[1],
@@ -1358,8 +1397,6 @@ def append_axes(ax, size=0.1, pad=0.1, position="right", extend=False):
 ####################
 # Legend Helpers
 def hist_legend(ax=None, **kwargs):
-    from matplotlib.lines import Line2D
-
     if ax is None:
         ax = plt.gca()
 
