@@ -9,7 +9,11 @@ from typing import TYPE_CHECKING, Any, Iterable, Sequence
 import numpy as np
 from matplotlib import markers
 from matplotlib.path import Path
-from uhi.numpy_plottable import ensure_plottable_histogram
+from uhi.numpy_plottable import (
+    Kind,
+    NumPyPlottableHistogram,
+    ensure_plottable_histogram,
+)
 from uhi.typing.plottable import PlottableAxis, PlottableHistogram
 
 if TYPE_CHECKING:
@@ -27,7 +31,7 @@ def isLight(rgb):
 def get_plottable_protocol_bins(
     axis: PlottableAxis,
 ) -> tuple[np.ndarray, np.ndarray | None]:
-    out = np.arange(len(axis) + 1).astype(float)
+    out: np.ndarray = np.arange(len(axis) + 1).astype(float)
     if isinstance(axis[0], tuple):  # Regular axis
         out[0] = axis[0][0]
         out[1:] = [axis[i][1] for i in range(len(axis))]  # type: ignore[index]
@@ -38,24 +42,28 @@ def get_plottable_protocol_bins(
 
 
 def hist_object_handler(
-    hist: (
+    hist_like: (
         ArrayLike | PlottableHistogram | tuple[ArrayLike | None, ...] | list[ArrayLike]
     ),
     *bins: Sequence[float | None],
 ) -> PlottableHistogram:
     if not bins or all(b is None for b in bins):
-        if isinstance(hist, list):
-            if not bins and len(hist) > 0 and not isinstance(hist[0], (list, Real)):
-                hist = tuple(hist)
+        if isinstance(hist_like, list):
+            if (
+                not bins
+                and len(hist_like) > 0
+                and not isinstance(hist_like[0], (list, Real))
+            ):
+                hist_like = tuple(hist_like)
             else:
-                hist = (np.asarray(hist), None)
-        elif isinstance(hist, np.ndarray):
-            hist = (hist, None)
-        hist_obj = ensure_plottable_histogram(hist)
-    elif isinstance(hist, PlottableHistogram):
-        hist_obj = hist
+                hist_like = (np.asarray(hist_like), None)
+        elif isinstance(hist_like, np.ndarray):
+            hist_like = (hist_like, None)
+        hist_obj = ensure_plottable_histogram(hist_like)
+    elif isinstance(hist_like, PlottableHistogram):
+        hist_obj = hist_like
     else:
-        hist_obj = ensure_plottable_histogram((hist, *bins))
+        hist_obj = ensure_plottable_histogram((hist_like, *bins))
 
     if len(hist_obj.axes) not in {1, 2}:
         msg = "Must have only 1 or 2 axes"
@@ -102,8 +110,8 @@ def _process_histogram_parts_iter(
 ) -> Iterable[PlottableHistogram]:
     original_bins: tuple[Sequence[float], ...] = bins  # type: ignore[assignment]
 
-    for hist in hists:
-        h = hist_object_handler(hist, *bins)
+    for hist_like in hists:
+        h = hist_object_handler(hist_like, *bins)
         current_bins: tuple[Sequence[float], ...] = tuple(
             get_plottable_protocol_bins(a)[0]  # type: ignore[misc]
             for a in h.axes  # type: ignore[misc]
@@ -145,6 +153,7 @@ def get_plottables(
     stack=False,
     density=False,
     binwnorm=None,
+    xoffsets=False,
 ):
     """
     Generate plottable histograms from various histogram data sources.
@@ -189,10 +198,12 @@ def get_plottables(
     binwnorm : float, optional
         If true, convert sum weights to bin-width-normalized, with unit equal to
             supplied value (usually you want to specify 1.)
+    xoffsets : bool | float | iterable, optional
+        Offset for x-axis values.
 
     Returns
     -------
-    plottables : list of Plottable
+    plottables : list of EnhancedPlottableHistogram
         Processed histogram objects ready for plotting.
     (flow_bins, underflow, overflow) : tuple
         Flow bin information for handling underflow and overflow values.
@@ -203,7 +214,16 @@ def get_plottables(
     hists = list(process_histogram_parts(H, bins))
     final_bins, _ = get_plottable_protocol_bins(hists[0].axes[0])
 
-    for h in hists:
+    if xoffsets is True:
+        parsed_offsets = []
+        widths = np.diff(final_bins)
+        sub_bin_width = widths / (len(hists) + 1)
+        for i in range(len(hists)):
+            parsed_offsets.append(sub_bin_width * (i + 1))
+        xoffsets = parsed_offsets
+    else:
+        xoffsets = [None] * len(hists)
+    for h, xoffset in zip(hists, xoffsets):
         value, variance = np.copy(h.values()), h.variances()
         if has_variances := variance is not None:
             variance = np.copy(variance)
@@ -241,7 +261,11 @@ def get_plottables(
 
         # Set plottables
         if flow in ("none", "hint"):
-            plottables.append(Plottable(value, edges=final_bins, variances=variance))
+            plottables.append(
+                EnhancedPlottableHistogram(
+                    value, edges=final_bins, variances=variance, xoffsets=xoffset
+                )
+            )
         elif flow == "show":
             _flow_bin_size: float = np.max(
                 [0.05 * (final_bins[-1] - final_bins[0]), np.mean(np.diff(final_bins))]
@@ -257,7 +281,11 @@ def get_plottables(
                 value = np.r_[value, overflow]
                 if has_variances:
                     variance = np.r_[variance, overflowv]
-            plottables.append(Plottable(value, edges=flow_bins, variances=variance))
+            plottables.append(
+                EnhancedPlottableHistogram(
+                    value, edges=flow_bins, variances=variance, xoffsets=xoffset
+                )
+            )
         elif flow == "sum":
             if underflow > 0:
                 value[0] += underflow
@@ -267,15 +295,27 @@ def get_plottables(
                 value[-1] += overflow
                 if has_variances:
                     variance[-1] += overflowv
-            plottables.append(Plottable(value, edges=final_bins, variances=variance))
+            plottables.append(
+                EnhancedPlottableHistogram(
+                    value, edges=final_bins, variances=variance, xoffsets=xoffset
+                )
+            )
         else:
-            plottables.append(Plottable(value, edges=final_bins, variances=variance))
+            plottables.append(
+                EnhancedPlottableHistogram(
+                    value, edges=final_bins, variances=variance, xoffsets=xoffset
+                )
+            )
 
     if w2 is not None:
         for _w2, _plottable in zip(
-            w2.reshape(len(plottables), len(final_bins) - 1), plottables
+            np.array(w2).reshape(len(plottables), len(final_bins) - 1), plottables
         ):
-            _plottable.variances = _w2
+            _plottable.set_variances(_w2)
+            _plottable.method = w2method
+
+    for _plottable in plottables:
+        if _plottable.variances() is not None:
             _plottable.method = w2method
 
     if w2 is not None and yerr is not None:
@@ -294,10 +334,10 @@ def yerr_plottables(plottables, bins, yerr=None):
 
     Parameters
     ----------
-    plottables : list of Plottable
-        List of Plottable objects.
+    plottables : list of EnhancedPlottableHistogram
+        List of EnhancedPlottableHistogram objects.
     bins : iterable
-        Plottable bins.
+        EnhancedPlottableHistogram bins.
     yerr : iterable or bool, optional
         Histogram uncertainties. Following modes are supported:
         - True, sqrt(N) errors or poissonian interval when ``w2`` is specified
@@ -322,7 +362,7 @@ def yerr_plottables(plottables, bins, yerr=None):
         else:
             _yerr = None
             for _plottable in plottables:
-                _plottable.errors()
+                _plottable.errors(assume_variances_equal_values=True)
     else:
         _yerr = None
     if _yerr is not None:
@@ -362,10 +402,10 @@ def norm_stack_plottables(plottables, bins, stack=False, density=False, binwnorm
 
     Parameters
     ----------
-    plottables : list of Plottable
-        List of Plottable objects.
+    plottables : list of EnhancedPlottableHistogram
+        List of EnhancedPlottableHistogram objects.
     bins : iterable
-        Plottable bins.
+        EnhancedPlottableHistogram bins.
     stack : bool, optional
         Whether to stack or overlay non-axis dimension (if it exists). N.B. in
         contrast to ROOT, stacking is performed in a single call aka
@@ -395,13 +435,13 @@ def norm_stack_plottables(plottables, bins, stack=False, density=False, binwnorm
     if density is True:
         if stack:
             _total = np.sum(
-                np.array([plottable.values for plottable in plottables]), axis=0
+                np.array([plottable.values() for plottable in plottables]), axis=0
             )
             for plottable in plottables:
                 plottable.flat_scale(1.0 / np.sum(np.diff(bins) * _total))
         else:
             for plottable in plottables:
-                plottable.density = True
+                plottable.density()
     elif binwnorm is not None:
         for plottable, norm in zip(
             plottables, np.broadcast_to(binwnorm, (len(plottables),))
@@ -411,83 +451,216 @@ def norm_stack_plottables(plottables, bins, stack=False, density=False, binwnorm
 
     # Stack
     if stack and len(plottables) > 1:
-        from .utils import stack as stack_fun
+        from .utils import stack as stack_fun  # noqa: PLC0415
 
         plottables = stack_fun(*plottables)
 
 
-class Plottable:
-    def __init__(self, values, *, edges=None, variances=None, yerr=None):
-        self._values = np.array(values).astype(float)
-        self.variances = None
-        self._variances = None
-        self._has_variances = False
-        if variances is not None:
-            self._variances = np.array(variances).astype(float)
-            self.variances = np.array(variances).astype(float)
-            self._has_variances = True
+class EnhancedPlottableHistogram(NumPyPlottableHistogram):
+    """A container for histogram-like data, supporting error propagation and multiple plotting formats."""
+
+    def __init__(
+        self,
+        values,
+        *,
+        edges=None,
+        xoffsets=None,
+        variances=None,
+        yerr=None,
+        w2method="poisson",
+        kind=Kind.COUNT,
+    ):
+        """Initialize the EnhancedPlottableHistogram object with values, bin edges, optional variances, and error bars."""
+
+        super().__init__(values.astype(float), edges, variances=variances, kind=kind)
+
+        if isinstance(self._variances, np.ndarray) and self._variances.ndim == 0:
+            self._variances = None
+
+        self._binwnorm = False
         self._density = False
 
-        self.values = np.array(values).astype(float)
-        self.baseline = np.zeros_like(self.values)
-        self.edges = np.array(edges)
-        if self.edges is None:
-            self.edges = np.arange(len(values) + 1)
-        self.centers = self.edges[:-1] + np.diff(self.edges) / 2
-        self.method = "poisson"
+        self.baseline = np.zeros_like(self.values())
+        self.centers = self.axes[0].edges.mean(axis=1)
 
+        if xoffsets is not None:
+            self.centers = self.edges_1d()[:-1] + xoffsets
+
+        self.xerr_lo, self.xerr_hi = (
+            self.centers - self.edges_1d()[:-1],
+            self.edges_1d()[1:] - self.centers,
+        )
+
+        self.method = w2method
         self.yerr = yerr
-        assert self.variances is None or self.yerr is None
+
+        assert self.variances() is None or self.yerr is None
         if self.yerr is not None:
             self._errors_present = True
             self.yerr_lo, self.yerr_hi = yerr
         else:
             self._errors_present = False
             self.yerr_lo, self.yerr_hi = (
-                np.zeros_like(self.values),
-                np.zeros_like(self.values),
+                np.zeros_like(self.values()),
+                np.zeros_like(self.values()),
             )
+        self._hash = None
 
     def __eq__(self, other):
+        """Check equality between two EnhancedPlottableHistogram instances based on values(), variances(), and edges."""
         return np.all(
             [
-                np.array_equal(getattr(self, att), getattr(other, att))
-                for att in ["values", "variances", "edges"]
+                np.array_equal(self.values(), other.values()),
+                np.array_equal(self.variances(), other.variances()),
+                np.array_equal(self.edges_1d(), other.edges_1d()),
             ]
         )
 
-    def __repr__(self):
-        return f"Plottable({self.values}, {self.edges}, {self.variances}"
+    def __hash__(self):
+        """Return a hash of the EnhancedPlottableHistogram object based on its values, variances, and edges."""
+        if self._hash is None:
+            self._hash = hash(
+                (
+                    tuple(self.values().flatten()),
+                    tuple(
+                        self.variances().flatten()
+                        if self.variances() is not None
+                        else []
+                    ),
+                    tuple(self.edges_1d().flatten()),
+                )
+            )
+        return self._hash
 
-    def errors(self, method=None):
-        """Calculate errors with a provided method(w, w2) -> (lower_abs_val, upper_abs_val)"""
+    def __repr__(self):
+        """Return string representation of the EnhancedPlottableHistogram object."""
+        return f"EnhancedPlottableHistogram(values={self.values()}, edges={self.axes[0].edges}, variances={self.variances()})"
+
+    def __add__(self, other):
+        """
+        Add two EnhancedPlottableHistograms.
+        """
+        if not isinstance(other, EnhancedPlottableHistogram):
+            msg = (
+                "Can only add EnhancedPlottableHistogram to EnhancedPlottableHistogram."
+            )
+            raise TypeError(msg)
+        if len(self.axes) > 1:
+            msg = "Addition of multi-dimensional histograms is not supported."
+            raise NotImplementedError(msg)
+        if self.axes != other.axes:
+            msg = "Histograms must have the same axes to be added."
+            raise ValueError(msg)
+        if not np.allclose(self.centers, other.centers):
+            msg = "Histograms must have the same bin centers to be added."
+            raise ValueError(msg)
+        if self.kind != Kind.COUNT or other.kind != Kind.COUNT:
+            msg = "Histograms must be of kind COUNT to be added."
+            raise TypeError(msg)
+        if self.method != other.method:
+            msg = f"Histograms must have the same w2method to be added. (got {self.method} and {other.method})"
+            raise ValueError(msg)
+        if self._errors_present or other._errors_present:
+            msg = "Cannot add histograms with fixed errors."
+            raise RuntimeError(msg)
+        added_values = self.values() + other.values()
+        added_variances = None
+        if self._variances is not None and other._variances is not None:
+            added_variances = self._variances + other._variances
+        else:
+            added_variances = None
+        return EnhancedPlottableHistogram(
+            added_values,
+            edges=self.axes[0].edges,
+            variances=added_variances,
+            kind=self.kind,
+            w2method=self.method,
+        )
+
+    def __radd__(self, other):
+        if other == 0:
+            return self
+        return self.__add__(other)
+
+    def __mul__(self, factor):
+        if not isinstance(factor, (int, float)):
+            msg = "Factor must be a scalar (int or float)."
+            raise TypeError(msg)
+        if len(self.axes) > 1:
+            msg = "Scaling of multi-dimensional histograms is not supported."
+            raise NotImplementedError(msg)
+        if self._errors_present:
+            msg = "Cannot multiply a histogram with fixed errors."
+            raise RuntimeError(msg)
+        return EnhancedPlottableHistogram(
+            self.values() * factor,
+            edges=self.axes[0].edges,
+            variances=(
+                self.variances() * factor**2 if self.variances() is not None else None
+            ),
+            kind=self.kind,
+            w2method=self.method,
+        )
+
+    def __rmul__(self, factor):
+        return self.__mul__(factor)
+
+    def set_values(self, values: np.typing.NDArray[Any]) -> None:
+        """Set the values of the histogram."""
+        self._values = values
+
+    def set_variances(self, variances: np.typing.NDArray[Any] | None) -> None:
+        """Set the variances of the histogram."""
+        self._variances = variances
+
+    def edges_1d(self):
+        """Return the edges of the first axis as a 1D array."""
+        edges = np.empty(len(self.axes[0].edges) + 1, dtype=float)
+        edges[0] = self.axes[0].edges[0][0]
+        edges[1:] = [self.axes[0].edges[i][1] for i in range(len(self.axes[0]))]
+        return edges
+
+    def is_unweighted(self):
+        """Check if the histogram is unweighted."""
+        if self.variances() is None:
+            msg = "Variances are not set, cannot determine if histogram is unweighted."
+            raise RuntimeError(msg)
+        return np.allclose(self.variances(), np.around(self.variances()))
+
+    def errors(self, method=None, assume_variances_equal_values=False):
+        """
+        Calculate y-errors using a specified or inferred method ('poisson', 'sqrt', or callable).
+        The method should have signature method(sumw, sumw2) -> (lower_abs_val, upper_abs_val).
+        If variances is None and assume_variances_equal_values is True, the values will be used as variances.
+        """
+        if self._errors_present:
+            return
+        if assume_variances_equal_values and self.variances() is None:
+            self._variances = self.values()
+        if self.variances() is None:
+            return
         assert method in ["poisson", "sqrt", None] or callable(method)
-        variances = self.variances if self.variances is not None else self.values
         if method is None:
             method = self.method
             if method is None:
-                if np.allclose(variances, np.around(variances)):
-                    method = "poisson"
-                else:
-                    method = "sqrt"
+                method = "poisson" if self.is_unweighted() else "sqrt"
 
-        if self._errors_present:
-            return
-
-        def sqrt_method(values, _):
-            return values - np.sqrt(values), values + np.sqrt(values)
+        def sqrt_method(values, variances):
+            return values - np.sqrt(variances), values + np.sqrt(variances)
 
         def calculate_relative(method_fcn, variances):
-            return np.abs(method_fcn(self.values, variances) - self.values)
+            return np.abs(method_fcn(self.values(), variances) - self.values())
 
         if method == "sqrt":
-            self.yerr_lo, self.yerr_hi = calculate_relative(sqrt_method, variances)
+            self.yerr_lo, self.yerr_hi = calculate_relative(
+                sqrt_method, self.variances()
+            )
         elif method == "poisson":
             try:
-                from .error_estimation import poisson_interval
+                from .error_estimation import poisson_interval  # noqa: PLC0415
 
                 self.yerr_lo, self.yerr_hi = calculate_relative(
-                    poisson_interval, variances
+                    poisson_interval, self.variances()
                 )
             except ImportError:
                 warnings.warn(
@@ -496,97 +669,167 @@ class Plottable:
                     "will be set to ``sqrt(w2)``.",
                     stacklevel=2,
                 )
-                self.yerr_lo, self.yerr_hi = calculate_relative(sqrt_method, variances)
+                self.yerr_lo, self.yerr_hi = calculate_relative(
+                    sqrt_method, self.variances()
+                )
         elif callable(method):
-            self.yerr_lo, self.yerr_hi = calculate_relative(method, variances)
+            self.yerr_lo, self.yerr_hi = calculate_relative(method, self.variances())
         else:
             msg = "``method'' needs to be a callable or 'poisson' or 'sqrt'."
             raise RuntimeError(msg)
         self.yerr_lo = np.nan_to_num(self.yerr_lo, 0)
         self.yerr_hi = np.nan_to_num(self.yerr_hi, 0)
-        self.variances = self.values if not self._has_variances else self.variances
 
     def fixed_errors(self, yerr_lo, yerr_hi):
+        """Manually assign fixed lower and upper y-errors."""
         self.yerr_lo = yerr_lo
         self.yerr_hi = yerr_hi
         self._errors_present = True
 
     def scale(self, scale):
-        """Scale values and variances to match, errors are recalculated"""
-        self.values *= scale
-        if self.variances is not None:
-            self.variances *= scale * scale
-        self.errors()
+        """Apply a scaling factor to values and variances."""
+        if self._errors_present:
+            msg = "Cannot recompute errors when errors already present."
+            raise RuntimeError(msg)
+        self._values *= scale
+        if self.variances() is not None:
+            self._variances *= scale * scale
         return self
 
     def flat_scale(self, scale):
-        """Scale values by a flat coefficient. Errors are scaled directly to match"""
+        """Multiply values and errors by a flat scalar."""
         self.errors()
         self._errors_present = True
-        self.values *= scale
+        self._values *= scale
         self.yerr_lo *= scale
         self.yerr_hi *= scale
         return self
 
     def binwnorm(self):
-        """Scale values by a flat coefficient. Errors are scaled directly to match"""
-        self.errors()
-        self._errors_present = True
-        self.values /= np.diff(self.edges)
-        self.yerr_lo /= np.diff(self.edges)
-        self.yerr_hi /= np.diff(self.edges)
-        return self
+        """Normalize values and errors by the bin widths."""
+        if self._binwnorm:
+            return self
+        self._binwnorm = True
+        return self.flat_scale(1 / np.diff(self.edges_1d()))
 
-    def reset(self):
-        """Reset to original values"""
-        self.values = copy.deepcopy(self._values)
-        self.variances = copy.deepcopy(self._variances)
-        self._density = False
-        self.errors()
-        return self
-
-    @property
     def density(self):
-        return self._density
-
-    @density.setter
-    def density(self, boolean: bool):
-        if boolean and not self._density:
-            self.flat_scale(1 / np.sum(np.diff(self.edges) * self.values))
-        if not boolean:
-            self.reset()
-        self._density = boolean
+        """Normalize values and errors by the area."""
+        if self._density:
+            return self
+        self._density = True
+        return self.flat_scale(1 / np.sum(np.diff(self.edges_1d()) * self.values()))
 
     def to_stairs(self):
-        return {"values": self.values, "edges": self.edges, "baseline": self.baseline}
+        """Export data in a dictionary format suitable for stair plots (e.g., step histograms)."""
+        return {
+            "values": self.values(),
+            "edges": self.edges_1d(),
+            "baseline": self.baseline,
+        }
 
     def to_stairband(self):
+        """Export upper and lower stair-step error bands for uncertainty visualization."""
         self.errors()
         return {
-            "values": self.values + self.yerr_hi,
-            "edges": self.edges,
-            "baseline": self.values - self.yerr_lo,
+            "values": self.values() + self.yerr_hi,
+            "edges": self.edges_1d(),
+            "baseline": self.values() - self.yerr_lo,
         }
 
     def to_errorbar(self):
+        """Export data in a dictionary format for error bar plotting (e.g., matplotlib 'errorbar')."""
         self.errors()
         return {
             "x": self.centers,
-            "y": self.values,
+            "y": self.values(),
             "yerr": [self.yerr_lo, self.yerr_hi],
+            "xerr": [self.xerr_lo, self.xerr_hi],
         }
 
 
+def make_plottable_histogram(hist_like, **kwargs):
+    """
+    Convert a histogram to a plottable histogram.
+
+    Parameters
+    ----------
+    hist_like : Histogram object (e.g. Hist, boost_histogram, np.histogram, TH1)
+        The histogram to be converted.
+    **kwargs : dict, optional
+        Additional keyword arguments to pass to the EnhancedPlottableHistogram constructor.
+
+    Returns
+    -------
+    EnhancedPlottableHistogram
+        The converted plottable histogram.
+
+    Raises
+    ------
+    ValueError
+        If the input histogram is not 1D.
+    """
+    if isinstance(hist_like, EnhancedPlottableHistogram):
+        if kwargs:
+            warnings.warn(
+                "Additional keyword arguments are ignored when converting an already plottable histogram.",
+                stacklevel=2,
+            )
+        return hist_like
+
+    hist_obj = ensure_plottable_histogram(hist_like)
+    if len(hist_obj.axes) != 1:
+        msg = "Only 1D histograms are supported."
+        raise ValueError(msg)
+
+    axis = hist_obj.axes[0]
+
+    edges = np.arange(len(axis) + 1).astype(float)
+    if isinstance(axis[0], tuple):  # Regular axis
+        edges[0] = axis[0][0]
+        edges[1:] = [axis[i][1] for i in range(len(axis))]
+    else:  # Categorical axis
+        msg = "Categorical axis is not supported yet."
+        raise NotImplementedError(msg)
+
+    return EnhancedPlottableHistogram(
+        np.array(hist_obj.values()),  # copy to avoid further modification
+        edges=edges,
+        variances=np.array(hist_obj.variances()),  # copy to avoid further modification
+        kind=hist_obj.kind,
+        **kwargs,
+    )
+
+
+def _check_counting_histogram(hist_list):
+    """
+    Check that the histograms in the list are counting histograms.
+
+    Parameters
+    ----------
+    hist_list : list of PlottableHistogram
+
+    Raise
+    -----
+    ValueError
+        If the histogram is not a counting histogram.
+
+    """
+    for hist_obj in hist_list:
+        if hist_obj.kind != Kind.COUNT:
+            msg = f"The histogram must be a counting histogram, but the input histogram has kind {hist_obj.kind}."
+            raise ValueError(msg)
+
+
 def stack(*plottables):
-    baseline = np.nan_to_num(copy.deepcopy(plottables[0].values), 0)
+    baseline = np.nan_to_num(copy.deepcopy(plottables[0].values()), 0)
     for i in range(1, len(plottables)):
-        _mask = np.isnan(plottables[i].values)
+        _mask = np.isnan(plottables[i].values())
         _baseline = copy.deepcopy(baseline)
         _baseline[_mask] = np.nan
         plottables[i].baseline = _baseline
-        baseline += np.nan_to_num(plottables[i].values, 0)
-        plottables[i].values = np.nansum([plottables[i].values, _baseline], axis=0)
-        plottables[i].values[_mask] = np.nan
+        baseline += np.nan_to_num(plottables[i].values(), 0)
+        plottables[i].set_values(np.nansum([plottables[i].values(), _baseline], axis=0))
+        plottables[i].set_values(np.where(_mask, np.nan, plottables[i].values()))
     return plottables
 
 
